Learn R Programming

tipitaka (version 1.0.0)

pali_gt: Greater-than (>) comparison function for Pali words

Description

Note that all Pali string comparisons are case-insensitive. #' Also non-Pali characters are placed at the end of the alphabet and are considered equivalent to each other.

Usage

pali_gt(word1, word2)

Value

TRUE if word1 comes after word2 alphabetically

Arguments

word1

A first Pali word as a string

word2

A second Pali word as a string