Learn R Programming

tipitaka (version 1.0.0)

sutta_pitaka: All the books of the Sutta Pitaka

Description

A subset of tipitaka_names consisting of only the books of the Sutta Pitaka. These are easier to read if you call stringi::stri_unescape_unicode first.

Usage

sutta_pitaka

Arguments

Format

A tibble with the variables:

book

Abbreviated title

name

Full title

Examples

Run this code
# \donttest{
# Clean up the Unicode characters to make things more readable:
sutta_pitaka$name <-
  stringi::stri_unescape_unicode(sutta_pitaka$name)
# }
# \donttest{
# Count all the words in the Suttas:
sum(
  unique(
    tipitaka_long[tipitaka_long$book %in% sutta_pitaka$book, "total"]))
# }

Run the code above in your browser using DataLab