powered by
Note that all Pali string comparisons are case-insensitive. #' Also non-Pali characters are placed at the end of the alphabet and are considered equivalent to each other.
pali_gt(word1, word2)
A first Pali word as a string
A second Pali word as a string
TRUE if word1 comes after word2 alphabetically