Learn R Programming

tipitaka (version 0.1.2)

vinaya_pitaka: All the books of the Vinaya Pitaka

Description

A subset of tipitaka_names consisting of only the books of the Vinaya Pitaka. These are easier to read if you call stringi::stri_unescape_unicode first.

Usage

vinaya_pitaka

Arguments

Format

A tibble with the variables:

book

Abbreviated title

name

Full title

Examples

Run this code
# NOT RUN {
# Clean up the Unicode characters to make things more readble:
vinaya_pitaka$name <-
  stringi::stri_unescape_unicode(vinaya_pitaka$name)

# Count all the words in the Vinaya Pitaka:
sum(tipitaka_long[tipitaka_long$book %in% vinaya_pitaka$book, "n"])

# }

Run the code above in your browser using DataLab